@@ -877,16 +877,9 @@ mod timer {
     }
 }
 
-#[cfg(test)]
-pub(crate) fn rt() -> &'static tokio::runtime::Runtime {
-    static RT: once_cell::sync::OnceCell<tokio::runtime::Runtime> =
-        once_cell::sync::OnceCell::new();
-    RT.get_or_init(|| tokio::runtime::Runtime::new().unwrap())
-}
-
 #[cfg(test)]
 mod test {
-    use super::{rt, Session};
+    use super::Session;
     use crate::{
         config::Config,
         frame::{Flag, Flags, Frame, FrameCodec, GoAwayCode, Type},
@@ -997,7 +990,7 @@ mod test {
 
     #[test]
     fn test_open_exist_stream() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
 
         rt.block_on(async {
             let (remote, local) = MockSocket::new();
@@ -1055,7 +1048,7 @@ mod test {
     // the test will remain stuck and cannot be finished.
     #[test]
     fn test_close_session_on_stream_opened() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
 
         rt.block_on(async {
             let (remote, local) = MockSocket::new();
@@ -1101,7 +1094,7 @@ mod test {
 
     #[test]
     fn test_open_too_many_stream() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
 
         rt.block_on(async {
             let (remote, local) = MockSocket::new();
@@ -1153,7 +1146,7 @@ mod test {
 
     #[test]
     fn test_remote_does_not_respond_go_away() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
 
         rt.block_on(async {
             let (_remote, local) = MockSocket::new();
