@@ -447,9 +447,11 @@ impl Drop for StreamHandle {
     fn drop(&mut self) {
         if !self.unbound_event_sender.is_closed() && self.state != StreamState::Closed {
             let event = StreamEvent::Closed(self.id);
-            // LocalClosing means that local have sent Fin to the remote and waiting for a response.
-            // if not, we should send Rst first
-            if self.state != StreamState::LocalClosing {
+            if self.state == StreamState::LocalClosing {
+                // LocalClosing means that local have sent Fin to the remote and waiting for a response.
+                // So, here only need to send a cleanup message
+                let _ignore = self.unbound_event_sender.unbounded_send(event);
+            } else {
                 let mut flags = self.get_flags();
                 flags.add(Flag::Rst);
                 let frame = Frame::new_window_update(flags, self.id, 0);
@@ -457,8 +459,8 @@ impl Drop for StreamHandle {
 
                 // Always successful unless the session is dropped
                 let _ignore = self.unbound_event_sender.unbounded_send(rst_event);
+                let _ignore = self.unbound_event_sender.unbounded_send(event);
             }
-            let _ignore = self.unbound_event_sender.unbounded_send(event);
         }
     }
 }
@@ -499,7 +501,6 @@ mod test {
     use crate::{
         config::INITIAL_STREAM_WINDOW,
         frame::{Flag, Flags, Frame, Type},
-        session::rt,
     };
     use bytes::BytesMut;
     use futures::{
@@ -511,7 +512,7 @@ mod test {
 
     #[test]
     fn test_drop() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
         rt.block_on(async {
             let (_frame_sender, frame_receiver) = channel(2);
             let (unbound_sender, mut unbound_receiver) = unbounded();
@@ -539,7 +540,7 @@ mod test {
 
     #[test]
     fn test_drop_with_state_reset() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
         rt.block_on(async {
             let (mut frame_sender, frame_receiver) = channel(2);
             let (unbound_sender, mut unbound_receiver) = unbounded();
@@ -574,7 +575,7 @@ mod test {
 
     #[test]
     fn test_drop_with_state_local_close() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
         rt.block_on(async {
             let (_frame_sender, frame_receiver) = channel(2);
             let (unbound_sender, mut unbound_receiver) = unbounded();
@@ -608,7 +609,7 @@ mod test {
 
     #[test]
     fn test_data_large_than_recv_window() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
         rt.block_on(async {
             let (mut frame_sender, frame_receiver) = channel(2);
             let (unbound_sender, mut unbound_receiver) = unbounded();
@@ -651,7 +652,7 @@ mod test {
     // the protocol cannot be opened
     #[test]
     fn test_open_stream_with_data() {
-        let rt = rt();
+        let rt = tokio::runtime::Runtime::new().unwrap();
         rt.block_on(async {
             let (_frame_sender, frame_receiver) = channel(2);
             let (unbound_sender, mut unbound_receiver) = unbounded();
